@@ -3,19 +3,19 @@
 
 #helper function for checkMP
 
-.findNijPjk<-function(Nijk=Nijk, Nij=Nij, trans, row=1){
-  i<-Nijk[row,1]
-  j<-Nijk[row,2]
-  k<-Nijk[row,3]
+.findNijPjk<-function(Nijk = Nijk, Nij = Nij, trans, row = 1){
+  i <- Nijk[row,1]
+  j <- Nijk[row,2]
+  k <- Nijk[row,3]
   
-  fromCh<-as.character(j)
-  toCh<-as.character(k)
-  Pjk<-trans[fromCh,toCh]
+  fromCh <- as.character(j)
+  toCh <- as.character(k)
+  Pjk <- trans[fromCh,toCh]
   
-  m1<-which(Nij[,1]==i)
-  m2<-which(Nij[,2]==j)
-  m<-c(m1,m2)
-  return(Nij[m[anyDuplicated(m)],3]*Pjk)
+  m1 <- which(Nij[, 1] == i)
+  m2 <- which(Nij[, 2] == j)
+  m <- c(m1, m2)
+  return(Nij[m[anyDuplicated(m)], 3] * Pjk)
 }
 
 
@@ -56,47 +56,47 @@
 #' @export
 
 # check if the sequence holds the Markov property
-verifyMarkovProperty <- function(sequence, verbose=TRUE) {
+verifyMarkovProperty <- function(sequence, verbose = TRUE) {
   
   #fitting the markovchain
   
-  transMatrix<-markovchainFit(data=sequence)$estimate@transitionMatrix
+  transMatrix <- markovchainFit(data = sequence)$estimate@transitionMatrix
   
   #make the (n-2)x3 matrix for observations
-  subSample<-sequence[1:(length(sequence)-(length(sequence)%%3))]
+  subSample<-sequence[1:(length(sequence) - (length(sequence)%%3))]
   
-  seqSet1<-matrix(c(subSample[1:(length(subSample)-2)],
-                    subSample[2:(length(subSample)-1)],
+  seqSet1<-matrix(c(subSample[1:(length(subSample) - 2)],
+                    subSample[2:(length(subSample) - 1)],
                     subSample[3:(length(subSample))]
-  ),ncol=3) #fill the matrix in reverse order so position 11 is the first obersvation,12 second and 13 third
+  ),ncol = 3) #fill the matrix in reverse order so position 11 is the first obersvation,12 second and 13 third
   #compute row frequencies
   temp<-as.data.frame(seqSet1)
-  Nijk<-aggregate(temp, by=temp, length)[1:(ncol(temp)+1)]
+  Nijk<-aggregate(temp, by = temp, length)[1:(ncol(temp) + 1)]
   
-  seqSet2<-seqSet1[,-3] #make matrix of couples
-  temp2<-as.data.frame(seqSet2)
-  Nij<-aggregate(temp2, by=temp2, length)[1:(ncol(temp2)+1)] #rowfrequencies included
+  seqSet2 <- seqSet1[, -3] #make matrix of couples
+  temp2 <- as.data.frame(seqSet2)
+  Nij <- aggregate(temp2, by = temp2, length)[1:(ncol(temp2) + 1)] #rowfrequencies included
   
   
-  test<-c(length=dim(Nijk)[1])
+  test<-c(length = dim(Nijk)[1])
   #compute the test statistic
   invisible(lapply(seq_len(dim(Nijk)[1]),function(i)
     {
-    foundNijPjk<-.findNijPjk(Nijk=Nijk, Nij=Nij, trans=transMatrix, row=i)
+    foundNijPjk <- .findNijPjk(Nijk = Nijk, Nij = Nij, trans = transMatrix, row = i)
     test[i] <<- ((Nijk[i,4]-foundNijPjk)^2)/foundNijPjk
   })
   )
-  statistic<-sum(test)
+  statistic <- sum(test)
   #return value of the test statistic and test at confience level 95% and 99%
   
   #dof
   
-  dof=length(unique(sequence))^3
+  dof = length(unique(sequence))^3
   
   
   pvalue <- 1-pchisq(q = statistic,df = dof)
   
-  out<-list(statistic=statistic,dof=dof,p.value=pvalue)
+  out <- list(statistic = statistic,dof = dof,p.value = pvalue)
   
   # previous version
   # n <- length(sequence)
@@ -179,7 +179,7 @@ verifyMarkovProperty <- function(sequence, verbose=TRUE) {
   #     # store the result corresponding to present state and future state
   #     out[[paste0(present, future)]] <- res
   
-  if (verbose==TRUE) {
+  if (verbose == TRUE) {
     cat("Testing markovianity property on given data sequence\n")
     cat("Chi - square statistic is:",statistic," degrees of freedom are:",dof," and corresponding p-value is:",pvalue,"\n")  
   }
@@ -193,7 +193,7 @@ verifyMarkovProperty <- function(sequence, verbose=TRUE) {
 #' @export
 
 # check if sequence is of first order or of second order
-assessOrder <- function(sequence, verbose=TRUE) {
+assessOrder <- function(sequence, verbose = TRUE) {
   
   # length of sequence
   n <- length(sequence)
@@ -214,7 +214,7 @@ assessOrder <- function(sequence, verbose=TRUE) {
     for(i in 1:(n - 2)) {
       if(present == sequence[i + 1]) {
         past <- sequence[i]
-        future <- sequence[i+2]
+        future <- sequence[i + 2]
         mat[past, future] <- mat[past, future] + 1 
       }
     }
@@ -225,12 +225,12 @@ assessOrder <- function(sequence, verbose=TRUE) {
   }
   
   k <- nelements
-  df <- k*(k-1)^2
+  df <- k * (k - 1)^2
   pvalue <- 1-pchisq(q = TStat, df)
   out <- list(statistic = TStat[[1]], p.value = pvalue[[1]])
   
   # returning the output
-  if (verbose==TRUE) {
+  if (verbose == TRUE) {
     cat("The assessOrder test statistic is: ", TStat, " the Chi-Square d.f. are: ", df, " the p-value is: ", pvalue, "\n")
   }
   
@@ -241,7 +241,7 @@ assessOrder <- function(sequence, verbose=TRUE) {
 #' @export
 
 # check if sequence is stationary
-assessStationarity <- function(sequence, nblocks, verbose=TRUE) {
+assessStationarity <- function(sequence, nblocks, verbose = TRUE) {
   
   # length of sequence
   n <- length(sequence)
@@ -262,11 +262,11 @@ assessStationarity <- function(sequence, nblocks, verbose=TRUE) {
   for(i in states) {
     
     # init matrix
-    mat <- matlab::zeros(nblocks, nstates)
+    mat <- matlab :: zeros(nblocks, nstates)
     dimnames(mat) <- list(1:nblocks, states)
     
     # compute the transition matrix from sequence
-    for(j in 1:(n-1)) {
+    for(j in 1:(n - 1)) {
       if(sequence[j] == i) {
         # row index
         b <- ceiling(j / blocksize) 
@@ -303,8 +303,8 @@ assessStationarity <- function(sequence, nblocks, verbose=TRUE) {
   k <- nstates
   
   # degree of freedom
-  df <- k * (nblocks - 1) * (k-1)
-  pvalue <- 1-pchisq(TStat, df)
+  df <- k * (nblocks - 1) * (k - 1)
+  pvalue <- 1 - pchisq(TStat, df)
   
   # returning the output
   
@@ -330,7 +330,7 @@ assessStationarity <- function(sequence, nblocks, verbose=TRUE) {
   dimnames(mat) <- list(states, states)
   
   # populate transition matrix
-  for(i in 1:(n-1)) {
+  for(i in 1:(n - 1)) {
     from <- sequence[i]
     to <- sequence[i+1]
     mat[from, to] <- mat[from, to] + 1
@@ -372,16 +372,16 @@ assessStationarity <- function(sequence, nblocks, verbose=TRUE) {
 #' verifyEmpiricalToTheoretical(data=sequence,object=theoreticalMc)
 #' 
 
-verifyEmpiricalToTheoretical <- function(data, object, verbose=TRUE) {
+verifyEmpiricalToTheoretical <- function(data, object, verbose = TRUE) {
   
-  if (!class(object)=='markovchain') stop("Error! Object should belong to the markovchain class")
+  if (!class(object) == 'markovchain') stop("Error! Object should belong to the markovchain class")
   if (missing(data) | missing(object)) stop("Error! Required inputs missing")
   if (!(class(data) %in% c("matrix","character","numeric"))) stop("Error! Data should be either a raw transition matrix or 
                                                                   either a character or a numeric element")
   
   if (class(data) %in% c("character","numeric")) data<-createSequenceMatrix(stringchar = data)
   
-  if (length(setdiff(names(data),names(object)))>0) stop("Error! Empirical and theoretical tm have different support")
+  if (length(setdiff(names(data),names(object))) > 0) stop("Error! Empirical and theoretical tm have different support")
   
   # (possibly rearrange columns and rownames)
   
@@ -394,25 +394,25 @@ verifyEmpiricalToTheoretical <- function(data, object, verbose=TRUE) {
   
   for (i in 1:dim(object)) {
     for (j in 1:dim(object)) {
-      if (data[i,j]>0&object[i,j]>0) statistic <- statistic + data[i,j]*log(data[i,j]/(f_i_dot[i]*object[i,j]))
+      if (data[i, j]>0&object[i, j]>0) statistic <- statistic + data[i, j]*log(data[i, j]/(f_i_dot[i]*object[i, j]))
     }
   }
   
   statistic <- statistic * 2
   
-  null_elements <- sum(object@transitionMatrix==0)
+  null_elements <- sum(object@transitionMatrix == 0)
   
-  dof <- dim(object) * (dim(object)-1) - null_elements #r(r-1) - c, c null element ob objects
+  dof <- dim(object) * (dim(object) - 1) - null_elements #r(r-1) - c, c null element ob objects
   
-  p.value <- 1 - pchisq(q=statistic,df=dof)
+  p.value <- 1 - pchisq(q = statistic,df = dof)
   
-  if (verbose==TRUE) {
+  if (verbose == TRUE) {
     cat("Testing whether the\n");print(data);cat("transition matrix is compatible with\n");print(object@transitionMatrix);print("theoretical transition matrix")
     cat("ChiSq statistic is",statistic,"d.o.f are",dof,"corresponding p-value is",p.value,"\n")  
   }
 
   #return output
-  out <- list(statistic=statistic, dof=dof,pvalue=p.value)
+  out <- list(statistic = statistic, dof = dof,pvalue = p.value)
   
   return(out)
 }
@@ -422,17 +422,17 @@ verifyEmpiricalToTheoretical <- function(data, object, verbose=TRUE) {
 
 .checkMatrix4Homogeneity<-function(matr) {
   out<-TRUE
-  if (length(colnames(matr))==0) {message("Error! No colnames in input matrix"); out=FALSE}
-  if (length(rownames(matr))==0) {message("Error! No rownames in input matrix"); out=FALSE}
+  if (length(colnames(matr)) == 0) {message("Error! No colnames in input matrix"); out = FALSE}
+  if (length(rownames(matr)) == 0) {message("Error! No rownames in input matrix"); out = FALSE}
   if (!all.equal(rownames(matr),colnames(matr))) {message("Error! Colnames <> Rownames")}
-  if (any(matr<0)) {message("Error! Negative elements"); out=FALSE}
+  if (any(matr<0)) {message("Error! Negative elements"); out = FALSE}
   return(out)
 }
 
 .addNamedColumns <- function(matr, fullnames) {
   if ( length( setdiff(names(matr),fullnames) )>0)  stop("Error! Names in matr not in fullnames")
   fullnames<-sort(fullnames)
-  newMatr<-matrix(0,nrow=length(fullnames),ncol=length(fullnames),dimnames = list(fullnames,fullnames))
+  newMatr<-matrix(0,nrow = length(fullnames),ncol = length(fullnames),dimnames = list(fullnames,fullnames))
   
   current_support = colnames(matr)
   current_dim = dim(matr)
@@ -446,7 +446,7 @@ verifyEmpiricalToTheoretical <- function(data, object, verbose=TRUE) {
       row_to_write <-match(x=which_row_trans,table = fullnames)
       col_to_write <-match(x=which_col_trans,table = fullnames)
       # write element into the pooled table
-      newMatr[row_to_write,col_to_write]<-newMatr[row_to_write,col_to_write]+item
+      newMatr[row_to_write,col_to_write] <- newMatr[row_to_write,col_to_write] + item
     }
   }
 
@@ -471,16 +471,16 @@ verifyEmpiricalToTheoretical <- function(data, object, verbose=TRUE) {
 #' data(kullback)
 #' verifyHomogeneity(inputList=kullback,verbose=TRUE)
 #' 
-verifyHomogeneity<-function(inputList, verbose=TRUE) {
-  if (class(inputList)!="list") stop("Error! inputList should be a string")
-  if (length(inputList)<2) stop("Error! inputList length lower than 2")
+verifyHomogeneity<-function(inputList, verbose = TRUE) {
+  if (class(inputList) != "list") stop("Error! inputList should be a string")
+  if (length(inputList) < 2) stop("Error! inputList length lower than 2")
   
   #checks whether all inputs can be put as transition matrices
   
   for (i in 1:length(inputList)) {
-    if (class(inputList[[i]])=='matrix') {
+    if (class(inputList[[i]]) == 'matrix') {
       checks<-.checkMatrix4Homogeneity(inputList[[i]])
-      if (!checks) stop("Error! Element ",i," to be checked")
+      if (!checks) stop("Error! Element ", i, " to be checked")
     } else {
       inputList[[i]]<-createSequenceMatrix(stringchar = inputList[[i]]) #convert all elements into transition matrices
     }
@@ -493,8 +493,8 @@ verifyHomogeneity<-function(inputList, verbose=TRUE) {
   }
   all.names<-sort(unique(all.names))
   ##initialize
-  PooledRawTransitionMatrix<-matrix(0,nrow=length(all.names),ncol=length(all.names),dimnames = list(all.names, all.names))
-  RowSumsMatrix<-matrix(0, nrow=length(inputList),ncol=length(all.names),dimnames = list(1:length(inputList),all.names))
+  PooledRawTransitionMatrix <- matrix(0,nrow = length(all.names),ncol = length(all.names),dimnames = list(all.names, all.names))
+  RowSumsMatrix <- matrix(0, nrow = length(inputList),ncol=length(all.names),dimnames = list(1:length(inputList),all.names))
   ##sum for each element in the list
   
   for (k in 1:length(inputList)) {
@@ -503,12 +503,12 @@ verifyHomogeneity<-function(inputList, verbose=TRUE) {
     
     for (i in 1:current_dim[1]) { #cycle on row
       for (j in 1:current_dim[2]) { #cycle on cols
-        num_trans<-inputList[[k]][i,j] #take the element
-        which_row_trans<-current_support[i] #define current row and cols
-        which_col_trans<-current_support[j]
+        num_trans<-inputList[[k]][i, j] #take the element
+        which_row_trans <- current_support[i] #define current row and cols
+        which_col_trans <- current_support[j]
         # lookup element in the pooled table
-        row_to_write <-match(x=which_row_trans,table = all.names)
-        col_to_write <-match(x=which_col_trans,table = all.names)
+        row_to_write <-match(x = which_row_trans,table = all.names)
+        col_to_write <-match(x = which_col_trans,table = all.names)
         # write element into the pooled table
         PooledRawTransitionMatrix[row_to_write,col_to_write]=PooledRawTransitionMatrix[row_to_write,col_to_write]+num_trans
       }
@@ -517,12 +517,12 @@ verifyHomogeneity<-function(inputList, verbose=TRUE) {
   
   #create the matrix of rowsums fij.
   for (k in 1:length(inputList)) {
-    my_row_sums<-rowSums(inputList[[k]])
+    my_row_sums <- rowSums(inputList[[k]])
     current_support = names(my_row_sums)
     for (i in 1:length(current_support)) {
       my_element<-my_row_sums[i]
       col_to_write<-match(x=current_support[i],table = all.names)
-      RowSumsMatrix[k,col_to_write]<-RowSumsMatrix[k,col_to_write]+my_element
+      RowSumsMatrix[k, col_to_write]<-RowSumsMatrix[k, col_to_write] + my_element
     }
   }
   
@@ -530,18 +530,18 @@ verifyHomogeneity<-function(inputList, verbose=TRUE) {
   
   statistic <- 0
  # degreesOfFreedomLess <- 0
-  newInputList<-lapply(inputList,.addNamedColumns,fullnames=all.names)
-  number_of_transitions<-sapply(newInputList,sum)
-  total_transitions<-sum(number_of_transitions)
+  newInputList <- lapply(inputList, .addNamedColumns,fullnames = all.names)
+  number_of_transitions <- sapply(newInputList,sum)
+  total_transitions <- sum(number_of_transitions)
   
   for (s in 1:length(inputList)) { #cycle across inputs
     for (j in 1:length(all.names)) { #cycle across rows
       for (k in 1:length(all.names)) { #cycle across cols
-       if (any(newInputList[[s]][j,k]==0, number_of_transitions[s]==0, PooledRawTransitionMatrix[j,k]==0)) {
+       if (any(newInputList[[s]][j,k] == 0, number_of_transitions[s] == 0, PooledRawTransitionMatrix[j,k] == 0)) {
          statistic <- statistic + 0 # zero element in log expr does not contribute to statistics 
 #         degreesOfFreedomLess <- degreesOfFreedomLess +1
        } else {
-         statistic <- statistic + newInputList[[s]][j,k]*log((total_transitions*newInputList[[s]][j,k])/(number_of_transitions[s]*PooledRawTransitionMatrix[j,k]))
+         statistic <- statistic + newInputList[[s]][j, k] * log((total_transitions*newInputList[[s]][j, k])/(number_of_transitions[s]*PooledRawTransitionMatrix[j,k]))
        }
     }
     }
@@ -549,29 +549,16 @@ verifyHomogeneity<-function(inputList, verbose=TRUE) {
   
   statistic <- statistic * 2
   #dof (s-1)*(r^2-1)-#zeros
-  degrees_of_freedom <- (length(inputList)-1)*(length(all.names)^2-1)#-degreesOfFreedomLess
+  degrees_of_freedom <- (length(inputList) - 1)*(length(all.names)^2 - 1)#-degreesOfFreedomLess
   
-  p.value <- 1 - pchisq(q=statistic,df=degrees_of_freedom)
+  p.value <- 1 - pchisq(q = statistic,df = degrees_of_freedom)
   
-  if (verbose==TRUE) {
+  if (verbose == TRUE) {
     cat("Testing homogeneity of DTMC underlying input list \n")
     cat("ChiSq statistic is",statistic,"d.o.f are",degrees_of_freedom,"corresponding p-value is",p.value,"\n")  
   }
   
   #return output
-  out <- list(statistic=statistic, dof=degrees_of_freedom,pvalue=p.value)
-  
+  out <- list(statistic = statistic, dof = degrees_of_freedom,pvalue = p.value)
   return(out)
-  
-  
 }
-
-
-#' Example from Kullback and Kupperman Tests for Contingency Tables
-#' 
-#' A list of two matrices representing raw transitions between two states
-#' 
-#' @format A list containing two 6x6 non - negative integer matrices
-#' 
-#' @source Kullback, Kupperman Tests for Contingency Tables Technometrics
-"kullback"
\ No newline at end of file
